## PR description

Description of your PR. Fixes # (issue) (if applicable)

## Checklist

Before submitting a PR, please make sure:

- [ ] Tests are working (`make test`)
- [ ] Code is formatted correctly (`make style`, on errors try fix with `make format`)
- [ ] Copyright header is included
- [ ] All commits are signed-off  using `git commit -s`

- [ ] (new press) `mypress_press.py` is in the `presses` directory
- [ ] (new press) `MyPress` is in `__init__.py` 
- [ ] (new press) `README.md` is updated with a 1 liner about the new press in the Available presses section
- [ ] (new press) New press is in the `default_presses` list in `tests/default_presses.py`
- [ ] (new press) A docstring is provided that follows the same structure as the existing ones
